@@ -1,7 +1,4 @@
-from enum import Enum
-
-
-class Services(str, Enum):
+class Services:
     MOVIES_SEARCH_SERVICE: str = "movies_search_service"
     PROXY_AUTH_SERVICE: str = "proxy_auth_service"
     MOVIES_ADMIN_PANEL_SERVICE: str = "movies_admin_panel_service"
